Python Script: menusys
======================

Written By: Benjamin P. Trachtenberg
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

If you have any questions e-mail me
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Contact Information: e\_ben\_75-python@yahoo.com
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

LinkedIn: `Ben Trachtenberg <https://www.linkedin.com/in/ben-trachtenberg-3a78496>`__
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Docker Hub: `Docker Hub <https://hub.docker.com/r/btr1975>`__
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Requirements
~~~~~~~~~~~~

-  Nothing Specific besides Python 3.5 and above

Languages
~~~~~~~~~

-  Python

About
~~~~~

This is a library used to have a CLI menu system.

Functions included in v1.0.0
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

-  menu(menu\_dictionary, menu\_header, back\_function=None)
-  clear\_screen()

Functions added in v1.0.2
~~~~~~~~~~~~~~~~~~~~~~~~~

-  menu\_multi\_select(menu\_dictionary, menu\_header,
   back\_function=None)

Functions added in v1.0.3
~~~~~~~~~~~~~~~~~~~~~~~~~

-  make\_menu\_dict\_from\_dict(orig\_dict, dict\_key\_for\_display)

Functions added in v1.0.4
~~~~~~~~~~~~~~~~~~~~~~~~~

-  make\_menu\_dict\_from\_list(orig\_list)

Functions added in v1.1.1
~~~~~~~~~~~~~~~~~~~~~~~~~

-  word\_wrap\_string\_and\_print(string\_to\_wrap)
-  chunk\_up\_string(string\_to\_chunk, size\_of\_chunk=100)

Functions added in v1.1.2
~~~~~~~~~~~~~~~~~~~~~~~~~

-  word\_wrap\_string(string\_to\_wrap)
